@@ -45,7 +45,7 @@ def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric
     
     if api=="train_api":
 
-        model = l.lgb_model_train(X_train,y_train,X_test,y_test,params=params,num_rounds=num_rounds,early_stop=early_stop,log=log)
+        model = l.lgb_model_train(X_train,y_train,X_test,y_test,params=params,metric=metric,num_rounds=num_rounds,early_stop=early_stop,log=log)
         y_prob_uno = model.predict(X_test, num_iteration=model.best_iteration) 
         
     elif api=="skl_api":
